#
# spec file for package ripit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         real_version 4.0.0_beta20140508
Name:           ripit
Version:        3.9.90
Release:        3.1
Summary:        Perl Script to Create .ogg or .mp3 Files from an Audio CD
# This is not the real tarball version but as it's still in beta, we could have troubles
# to update to 4.0 final so just give it a lower version
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Grabbers
URL:            https://en.wikipedia.org/wiki/Ripit
Source:         http://www.suwald.com/ripit/%{name}-%{real_version}.tar.gz
Patch0:         %{name}-3.9.0-ogg.patch
Patch1:         %{name}-4.0.0-undefined_variables.patch
Patch2:         %{name}-man-spellfix.patch
Requires:       cdparanoia
Requires:       perl-CDDB_get
Requires:       perl-libwww-perl
Requires:       vorbis-tools
# Requires:       perl(MP3::Tag)
BuildArch:      noarch

%description
This Perl script makes it easy to create MP3 files from an audio CD. It
tries to find the artist and song titles with the help of CDDB.

%prep
%autosetup -p1 -n %{name}-%{real_version}

%build

%install
make prefix=%{buildroot}%{_prefix} etcdir=%{buildroot}/%{_sysconfdir}/%{name} install

%files
%doc README HISTORY LICENSE
%{_bindir}/ripit
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*
%{_mandir}/man1/*

%changelog
* Fri Feb 23 2024 Takashi Iwai <tiwai@suse.com>
- Drop hard-dependency on perl(MP3::Tag) which doesn't exist on TW;
  at least it'd allow package rebuilds again on TW
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Mar  5 2021 lars@linux-schulserver.de - 3.9.90
- require perl(MP3::Tag)
* Mon Feb  5 2018 lars@linux-schulserver.de
- use wikipedia URL, as the original domain is no longer valid
- added ripit-4.0.0-undefined_variables.patch to avoid errors if the
  user is using an old config file which does not define some variables
- added ripit-man-spellfix.patch from Debian which contains some
  spell fixes for the man page
- rebased ripit-3.9.0-ogg.patch
- use Productivity/Multimedia/CD/Grabbers as RPM group
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 4.0.0_beta20140508
  * Option --coversize takes a width or width x height format to which
    a given cover shall be resized using ImageMagick.
  * And when using MusicBrainz, an additional coverart source will
    be checked.
  * Some bugs related to options loop and ISRC have been fixed.
- Use download Url as source
- Some improvements
- Remove obsolete AUTHORS and %%clean sections
* Thu Nov 18 2010 hvogel@novell.com
- Update to version 3.9.0
  * Added options --coverart and --coverpath to select
    and add coverart to the metadata.
  * Added option --copycover to copy a cover from
    some place to each directory of encoded files.
  * Added option --precmd to execute a command before
    ripping starts and e.g. ensure presence of coverart.
  * Added option --trackoffset to add a constant
    value to the tracknumber in the tracktemplate.
  * Added options --vatag and --vastring to detect
    various artist style and split artist and track
    title.
  * Added option --cdcue to create cue-files
    (cue-sheets) to burn the (merged) wav.
  * Added option --isrc to detect ISRCs in audio
    data using icedax.
  * Added options --mblogin and --mbpass to submit
    detected ISRCs to MusciBrainz.
* Sat Apr 10 2010 davejplater@gmail.com
- Update to version 3.8.2 removed ripit-3.6.0-genre_list.patch due to
  upstream fix. Adapted ripit-3.6.0-ogg.patch to ripit-3.8.2-ogg.patch
- See the HISTORY file for many changes and fixes since version 3.6.0
* Mon Sep  8 2008 kssingvo@suse.de
- fixed stderr output of lame (bnc#419873)
* Mon Jun 18 2007 kssingvo@suse.de
- new version 3.6.0 with new features:
  * Fixed bug on special characters for tags during submission of
    CDDB entries.
  * Fixed unpleasent behaviour if Lame is not installed.
  * Fixed semi-bug on deletion of wavs using remote machines.
  * Added option --merge to merge tracks for gapless encoding.
  * Added option --resume to continue a previously started
    session.
  * Added option --ghost to split tracks with gaps into chunks of
    sound (at experimental stage).
  * Added options --prepend and --extend to enlarge chunks of
    sound when splitted with option --ghost.
  * Added option --ejectcmd to specify command used to control
    ejection/loading of CD.
  * Added option --ejectopt to specify options and arguments for
  - -ejectcmd.
  * Added optons --dpermission and --fpermission to set directory
    and file permissions.
  * Added option --md5sum to create MD5-sum files for each type of
    sound files.
  * Added option --nicerip to set niceness of ripping process.
  * Added option --core to allow several encoding processes on
    each machine.
  * Enhanced output from encoding process not to interfer with
    output of ripper.
  * Submission of CDDB entries uses sendmail, not mail or nail.
  * Some fine-tuning on detection of hidden-tracks and
    ghost-songs.
  * Enhanced detection of perl modules needed, Ripit depends not
    on CDDB_get 2.22 but 2.25 and newer, please update.
- changed specfile accordingly
* Tue Apr  3 2007 kssingvo@suse.de
- added perl-libwww-perl to Requires
* Wed Jun 28 2006 kssingvo@suse.de
- new version 3.5.1 with new features:
- new options: --normalize, --loop, --cdtoc
- global config file now included
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 mmj@suse.de
- update to version 3.4
* Wed May 11 2005 cthiel@suse.de
- update to version 3.3.7
- aligned ripit-ogg.diff
* Mon Mar 21 2005 mmj@suse.de
- Default to oggvorbis [#74015]
- Make the oggencoding quality better
* Wed Feb 23 2005 mmj@suse.de
- Update to version 3.3.3 which is a bugfix release since 3.3
* Wed Feb 16 2005 mmj@suse.de
- Update to version 3.3
* Wed Jan  5 2005 mmj@suse.de
- Update to version 3.1.1
* Mon Dec 20 2004 mmj@suse.de
- Update to version 3.0
* Mon Dec  6 2004 mmj@suse.de
- Update to version 2.8
* Thu Dec  2 2004 mmj@suse.de
- Update to version 2.7
* Tue Nov 23 2004 mmj@suse.de
- Update to version 2.6.2
* Tue Aug 31 2004 mmj@suse.de
- use proto version 6, we are in the age of UTF-8 now. When touching
  anyway also remove ^M's and greet properly. Thanks Bjoern Jacke.
* Tue Jan  6 2004 mmj@suse.de
- Update to version 2.4 which removes all problems with tmp file
  usage [#33812]
* Tue Oct 21 2003 mmj@suse.de
- Update to version 2.2 which has our patches included plus some
  small feature additions
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Use -q for oggenc instead of bitrate
- Allow outputdir without trailing slash
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
* Mon Aug 26 2002 mmj@suse.de
- Make the ripit script config noreplace, since we don't want to
  replace a users ripit script if modified for hers needs.
* Mon Aug  5 2002 mmj@suse.de
- Added ""'s around mkdir to have it not fail when title contains
  '.
* Tue May 14 2002 mmj@suse.de
- Requires perl-CDDB_get not perl-CDDB.
* Mon May 13 2002 mmj@suse.de
- Update to version 2.0 which includes OggVorbis support and also
  removes dependancy on xmcd. Defaults to OggVorbis.
* Mon Oct 15 2001 sf@suse.de
- added patch to be able to parse disc ID, genre and interpret
  as xmcd has changed the output of 'cda -toc'
* Wed Apr  4 2001 poeml@suse.de
- add convenience link ripit -> ripit.pl
- use BuildRoot
- drop %%{suse_check}
* Wed Dec 13 2000 poeml@suse.de
- updated README.SuSE
- removed executable flag on doc files
* Wed Dec 13 2000 bjacke@suse.de
- update to 1.8 and fix some security vulnerabilities
* Thu Jun  8 2000 uli@suse.de
- moved docs to %%{_docdir}
* Fri Apr 14 2000 dbloms@suse.de
- change the link for bladeenc
* Thu Jan  6 2000 dbloms@suse.de
- change /usr/bin/cat to /bin/cat
- noarch
* Thu Sep 30 1999 dbloms@suse.de
- insert a patch from marc@suse.de to set new defaults
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jun 10 1999 dbloms@suse.de
- fix bugs
* Mon May 17 1999 dbloms@suse.de
- create the package
